@@ -3,12 +3,12 @@ package TAP::Formatter::Session::TeamCity;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use TAP::Parser::Result::Test;
-use Time::HiRes qw( time );
+use TeamCity::Message qw( tc_message );
 
-use base qw(TAP::Formatter::Session);
+use base qw( TAP::Formatter::Session );
 
 {
     my @accessors = map { '_tc_' . $_ } qw(
@@ -508,68 +508,23 @@ sub _test_died_result_object {
 
 sub _tc_message {
     my $self         = shift;
-    my $message      = shift;
-    my $values       = shift;
+    my $type         = shift;
+    my $content      = shift;
     my $force_stdout = shift;
 
+    if ( ref $content ) {
+        $content->{flowId} ||= $self->name;
+    }
+
     my $handle = $force_stdout ? \*STDOUT : $self->_tc_output_handle;
-
-    my $tc_msg = "##teamcity[$message";
-
-    if ( ref $values ) {
-        for my $name ( sort keys %{$values} ) {
-            my $value = $values->{$name};
-            $tc_msg .= qq{ $name='} . _tc_escape($value) . q{'};
-        }
-
-        $tc_msg .= $self->_tc_message_timestamp
-            unless ref $values && $values->{timestamp};
-        $tc_msg .= $self->_tc_message_flow_id
-            unless ref $values && $values->{flowId};
-    }
-    else {
-        $tc_msg .= q{ '} . _tc_escape($values) . q{'} or die $!;
-    }
-
-    $tc_msg .= "]\n";
-
-    print {$handle} $tc_msg or die $!;
+    print {$handle} tc_message(
+        type    => $type,
+        content => $content,
+    ) or die $!;
 
     return;
 }
 
-sub _tc_message_timestamp {
-    my $now = time;
-
-    my ( $s, $mi, $h, $d, $mo, $y ) = ( gmtime($now) )[ 0 .. 5 ];
-
-    my $float = ( $now - int($now) );
-    return sprintf(
-        q{ timestamp='%4d-%02d-%02dT%02d:%02d:%02d.%03d'},
-        $y + 1900, $mo + 1, $d,
-        $h, $mi, $s,
-
-        # We only need 3 places of precision so if we multiply it be 1,000 we
-        # can just treat it as an integer.
-        $float * 1000,
-    );
-}
-
-sub _tc_message_flow_id {
-    my $self = shift;
-    return q{ flowId='} . _tc_escape( $self->name ) . q{'};
-}
-
-sub _tc_escape {
-    my $str = shift;
-
-    ( my $esc = $str ) =~ s{(['|\]])}{|$1}g;
-    $esc =~ s{\n}{|n}g;
-    $esc =~ s{\r}{|r}g;
-
-    return $esc;
-}
-
 1;
 
 __END__
