@@ -5,7 +5,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use TAP::Formatter::Session::TeamCity;
 
@@ -41,7 +41,7 @@ TAP::Formatter::TeamCity - Emit test results as TeamCity build messages
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -70,7 +70,7 @@ formatter simply treats skipped and TODO tests as ignored tests.
 
 =head1 SEE ALSO
 
-L<TeamCity::BuildMessages>
+L<TeamCity::Message>
 
 =head1 AUTHORS
 
